@@ -4,6 +4,7 @@
 from numpy import (
     array, concatenate, identity, multiply, ones_like, repeat,
 )
+from sgp4 import omm
 from sgp4.api import SGP4_ERRORS, Satrec
 
 from .constants import AU_KM, DAY_S, T0, tau
@@ -136,6 +137,23 @@ class EarthSatellite(VectorFunction):
         self._setup(satrec)
         return self
 
+    @classmethod
+    def from_omm(cls, ts, element_dict):
+        """Build an EarthSatellite from OMM text fields.
+
+        Provide a ``ts`` timescale object, and a Python dict of OMM
+        field names and values.  The timescale is used to build the
+        satellite's ``.epoch`` time.
+
+        """
+        self = cls.__new__(cls)
+        self.name = element_dict.get('OBJECT_NAME', None)
+        self.model = satrec = Satrec()
+        omm.initialize(satrec, element_dict)
+        self.epoch = ts._utc_jd(satrec.jdsatepoch, satrec.jdsatepochF)
+        self._setup(satrec)
+        return self
+
     def __str__(self):
         return self.target_name
 
