@@ -263,6 +263,21 @@ class Timescale(object):
                 return [strftime(format, item) for item in zip(*tup)]
             return strftime(format, tup)
 
+    def _utc_jd(self, whole, fraction):
+        # Switch from days to seconds.
+        seconds = whole * DAY_S
+        seconds2, fraction_s = divmod(fraction * DAY_S, 1.0)
+        seconds += seconds2
+
+        # Add an integer number of leap seconds.
+        seconds += interp(seconds, self._leap_utc, self._leap_offsets)
+
+        # Switch back to days.
+        whole, fraction = divmod(seconds, DAY_S)
+        fraction += fraction_s
+        fraction /= DAY_S
+        return self.tai_jd(whole, fraction)
+
     def tai(self, year=None, month=1, day=1, hour=0, minute=0, second=0.0,
             jd=None):
         """Build a `Time` from an International Atomic Time `calendar date`.
